import { visit } from "unist-util-visit";
import { isMatch, merge as lodashMerge } from "lodash";
import yaml from "yaml";
const jsonStringify = (dataToStringify) => {
    return JSON.stringify(dataToStringify, null, 2);
};
export const remarkMergeData = ({ data, lang, isYaml, merge, meta, parse, stringify, }) => {
    if (isYaml && typeof data !== "string") {
        throw new Error("If you use YAML, `data` has to be a string.");
    }
    const mergeFunction = merge || lodashMerge;
    // Wrapping yaml.parse is necessary to force the correct type overload
    const parseFunction = parse || isYaml ? (code) => yaml.parse(code) : JSON.parse;
    const stringifyFunction = stringify || isYaml ? yaml.stringify : jsonStringify;
    return (tree) => {
        visit(tree, "code", function (node) {
            if (node.lang && node.lang === lang) {
                if (meta) {
                    if (!node.meta) {
                        return;
                    }
                    const nodeMeta = Object.fromEntries(node.meta.split(" ").map((entry) => {
                        return entry.split("=");
                    }));
                    if (!isMatch(nodeMeta, meta)) {
                        // No metadata match found.
                        return;
                    }
                }
                const documentData = parseFunction(node.value);
                node.value = stringifyFunction(mergeFunction(isYaml ? parseFunction(data) : data, documentData));
            }
        });
    };
};
